@@ -1,8 +1,8 @@
 pub mod hash;
 
 pub fn clean_0x(s: &str) -> &str {
-    if s.starts_with("0x") {
-        &s[2..]
+    if let Some(stripped) = s.strip_prefix("0x") {
+        stripped
     } else {
         s
     }
